%global srcname authlib
%global pypi_name Authlib

# Many of the test requirements are not in epel9 yet
%if 0%{?el9}
%bcond_with tests
%else
%bcond_without tests
%endif

Name:           python-%{srcname}
Version:        1.0.1
Release:        1%{?dist}.1
Summary:        Build OAuth and OpenID Connect servers in Python

License:        BSD
URL:            https://github.com/lepture/authlib
Source0:        %{url}/archive/v%{version}/%{srcname}-%{version}.tar.gz
# https://github.com/lepture/authlib/issues/423

BuildArch:      noarch

BuildRequires:  python3dist(setuptools)

%global _description %{expand:
Python library for building OAuth and OpenID Connect servers. JWS, JWK, JWA,
JWT are included.}

%description %_description

%package -n     python3-%{srcname}
Summary:        %{summary}
BuildRequires:  python3-devel

%if %{with tests}
# Test dependencies
BuildRequires:  python3dist(cryptography)
BuildRequires:  python3dist(coverage)
BuildRequires:  python3dist(mock)
BuildRequires:  python3dist(pytest)

BuildRequires:  python3dist(flask)
BuildRequires:  python3dist(flask-sqlalchemy)

BuildRequires:  python3dist(httpx)
BuildRequires:  python3dist(pytest-asyncio)
BuildRequires:  python3dist(starlette)
BuildRequires:  python3dist(itsdangerous)
BuildRequires:  python3dist(sphinx)

BuildRequires:  python3dist(django)
BuildRequires:  python3dist(pytest-django)
%endif

# Runtime dependencies
BuildRequires:  python3dist(cryptography)
BuildRequires:  python3dist(requests)

%description -n python3-%{srcname} %_description

%prep
%autosetup -p1 -n %{srcname}-%{version}

%build
%py3_build

%install
%py3_install

%check
%if %{with tests}
%{__python3} -m pytest tests/core
%{__python3} -m pytest tests/flask
export DJANGO_SETTINGS_MODULE=tests.django.settings
%{__python3} -m pytest tests/django
%endif

%files -n python3-%{srcname}
%license LICENSE
%doc README.md
%{python3_sitelib}/%{srcname}
%{python3_sitelib}/%{pypi_name}-%{version}-py%{python3_version}.egg-info

%changelog
* Tue Jul 26 2022 Troy Dawson <tdawson@redhat.com> - 1.0.1-1.1
- Skip tests until dependencies are in epel9

* Tue Apr 12 2022 dkirwan <dkirwan@redhat.com> - 1.0.1-1
- Update to v1.0.1

* Thu Jan 27 2022 Kai A. Hiller <V02460@gmail.com> - 0.15.5-1
- Update to v1.15.5

* Fri Jan 21 2022 Fedora Release Engineering <releng@fedoraproject.org> - 0.15.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Thu Jul 29 2021 Kai A. Hiller <V02460@gmail.com> - 0.15.4-1
- Update to v1.15.4
- Make compatible with werkzeug 2

* Fri Jul 23 2021 Fedora Release Engineering <releng@fedoraproject.org> - 0.15.3-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Sat Jul 03 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.15.3-5
- Fix buidlroot↔buildroot typo

* Fri Jun 04 2021 Python Maint <python-maint@redhat.com> - 0.15.3-4
- Rebuilt for Python 3.10

* Mon Mar 29 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.15.3-3
- Enable “py3” tests since all of the dependencies are present

* Wed Jan 27 2021 Fedora Release Engineering <releng@fedoraproject.org> - 0.15.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Sun Jan 17 2021 Kai A. Hiller <V02460@gmail.com> - 0.15.3-1
- Update to v1.15.3

* Fri Dec 11 2020 Kai A. Hiller <V02460@gmail.com> - 0.15.2-1
- Update to v1.15.2

* Sun Oct 11 2020 Kai A. Hiller <V02460@gmail.com> - 0.15.0-1
- Update to v1.15.0

* Fri May 29 2020 Kai A. Hiller <V02460@gmail.com> - 0.14.3-1
- Initial package.
